@@ -6,10 +6,11 @@ from elasticsearch.helpers import scan
 from future.utils import string_types
 
 from pandagg.connections import get_connection
+from pandagg.query import Bool
 from pandagg.response import Response
-from pandagg.tree.mapping import Mapping
-from pandagg.tree.query import Query
-from pandagg.tree.aggs import Aggs
+from pandagg.tree.mapping.mapping import Mapping
+from pandagg.tree.query.abstract import Query
+from pandagg.tree.aggs.aggs import Aggs
 
 
 class Request(object):
@@ -36,6 +37,9 @@ class Request(object):
             s = Search()
             s = s.params(routing='user-1', preference='local')
         """
+        from_ = kwargs.pop("from_", None)
+        if from_ is not None:
+            kwargs["from"] = from_
         s = self._clone()
         s._params.update(kwargs)
         return s
@@ -86,6 +90,9 @@ class Request(object):
         s._params = self._params.copy()
         return s
 
+    def __copy__(self):
+        return self._clone()
+
 
 class Search(Request):
     def __init__(self, using=None, index=None, mapping=None):
@@ -120,6 +127,13 @@ class Search(Request):
 
     query.__doc__ = Query.query.__doc__
 
+    def bool(self, *args, **kwargs):
+        s = self._clone()
+        s._query = s._query.bool(*args, **kwargs)
+        return s
+
+    bool.__doc__ = Query.bool.__doc__
+
     def filter(self, *args, **kwargs):
         s = self._clone()
         s._query = s._query.filter(*args, **kwargs)
@@ -148,6 +162,17 @@ class Search(Request):
 
     must.__doc__ = Query.must.__doc__
 
+    def exclude(self, *args, **kwargs):
+        """Must not wrapped in filter context."""
+        s = self._clone()
+        s._query = s._query.filter(Bool(must_not=[Query(*args, **kwargs)]))
+        return s
+
+    def post_filter(self, *args, **kwargs):
+        s = self._clone()
+        s._post_filter = s._post_filter.query(*args, **kwargs)
+        return s
+
     def aggs(self, *args, **kwargs):
         s = self._clone()
         s._aggs = s._aggs.aggs(*args, **kwargs)
@@ -164,7 +189,7 @@ class Search(Request):
 
     def __iter__(self):
         """
-        Iterate over the hits.
+        Iterate over the hits. Return iterable of ``pandagg.response.Hit``.
         """
         return iter(self.execute())
 
@@ -545,6 +570,13 @@ class Search(Request):
 
         return es.delete_by_query(index=self._index, body=self.to_dict())
 
+    def __eq__(self, other):
+        return (
+            isinstance(other, Search)
+            and other._index == self._index
+            and other.to_dict() == self.to_dict()
+        )
+
     def __repr__(self):
         return json.dumps(self.to_dict(), indent=2)
 
@@ -602,5 +634,12 @@ class MultiSearch(Request):
         es = get_connection(self._using)
         return es.msearch(index=self._index, body=self.to_dict(), **self._params)
 
+    def __eq__(self, other):
+        return (
+            isinstance(other, Search)
+            and other._index == self._index
+            and other.to_dict() == self.to_dict()
+        )
+
     def __repr__(self):
         return json.dumps(self.to_dict(), indent=2)
